@@ -114,7 +114,10 @@ raster2dat <- function(x, FUN, maxpixels){
       FUN <- match.fun(FUN)   
       dat$ind <- factor(FUN(z))[dat$ind]
     } else {
-      nms <- layerNames(x)
+      ## names replace layerNames with raster version 2.0-04
+      rasterVersion <- as.character(packageVersion('raster'))
+      nms <- if (compareVersion(rasterVersion, '2.0-04') == -1) layerNames(x) else names(x)
+
       nms <- reorder(factor(nms), 1:nl)
       dat$ind <- nms[dat$ind]
     }
