@@ -8,13 +8,14 @@ setGeneric('levelplot')
 setMethod('levelplot',
           signature(x='Raster', data='missing'),
           definition=function(x, data=NULL, layers,
-            margin=TRUE, FUN.margin=mean, scales.margin=NULL,
+            margin=!(any(is.factor(x))), FUN.margin=mean, 
             maxpixels=1e5,
             par.settings=rasterTheme,
             between=list(x=0.5, y=0.2),
             as.table=TRUE,
             xlab='', ylab='', main='',
             names.attr,
+            scales=list(), scales.margin=NULL,
             xscale.components=xscale.raster,
             yscale.components=yscale.raster,
             zscaleLog=NULL,
@@ -26,19 +27,27 @@ setMethod('levelplot',
             if (!missing(layers)) {
               object <- subset(x, subset=layers)
             } else {object <- x}
-  
-            dat <- sampleRegular(object, size=maxpixels, asRaster=TRUE)
-            nms <- make.names(layerNames(dat))
 
+            ## names replace layerNames with raster version 2.0-04
+            rasterVersion <- as.character(packageVersion('raster'))
+            objNames <- if (compareVersion(rasterVersion, '2.0-04') == -1) layerNames(object) else names(object)
+            nms <- make.names(objNames)
+
+            ## Is factor?
+            isFactor <- all(is.factor(object)) ## TODO: different individual layers
+
+            ## The plot display a sample of the whole object defined with maxpixels
+            dat <- sampleRegular(object, size=maxpixels, asRaster=TRUE)
             ##Extract coordinates from (sampled) raster
             coords <- xyFromCell(dat, seq_len(ncell(dat)))
             
             ## Extract values 
             dat <- getValues(dat)
 
+            
             ## If zscale is not NULL, transform the values and choose a function
             ## to calculate the labels
-            if (!is.null(zscaleLog)){
+            if (!is.null(zscaleLog) && !isFactor){
               zlogbase <- if (is.logical(zscaleLog)) {
                 10
               } else {
@@ -90,17 +99,17 @@ setMethod('levelplot',
               
             } else { ## !isLonLat
               aspect='iso'
-              }
+            }
 
             if (region==FALSE) colorkey=FALSE
            
             has.colorkey <- (is.logical(colorkey) && colorkey) || is.list(colorkey)
-            if (region==TRUE && !has.colorkey) colorkey=has.colorkey=TRUE
+            ##            if (region==TRUE && !has.colorkey) colorkey=has.colorkey=TRUE
             has.margin <- nlayers(object)==1 && margin
             has.contour <- (contour==TRUE) ##(!missing(contour) && contour==TRUE)
 
             ## Build the zscale.components and colorkey paying attention to zscaleLog
-            if (!is.null(zscaleLog)){
+            if (!is.null(zscaleLog) && !isFactor){
               zscale <- zscale.components(zlim, zlogbase)
               if (has.colorkey){
                 colorkey.default=list(labels=zscale, raster=TRUE, interpolate=TRUE)
@@ -117,19 +126,38 @@ setMethod('levelplot',
               if (is.function(par.settings)) par.settings <- par.settings()
               par.settings=modifyList(par.settings,
                 list(
-                     layout.widths=list(right.padding=10),
-                     layout.heights=list(top.padding=10,
-                       xlab.key.padding=3)
-                     )
+                  layout.widths=list(right.padding=10),
+                  layout.heights=list(top.padding=10,
+                    xlab.key.padding=3)
+                  )
                 )
-              if (has.colorkey){## put the colorkey at the bottom to leave space for the margin
+              if (has.colorkey){ ## put the colorkey at the bottom to leave space for the margin
                 if (is.logical(colorkey)){
-                  colorkey=list(space='bottom')                
+                  colorkey=list(space='bottom')
                 } else {
                   colorkey=modifyList(colorkey, list(space='bottom'))
                 }}
             }
 
+            if (isFactor) {
+              rat <- data.frame(levels(object)[[1]])
+              classes <- as.factor(rat[,2]) #TODO: allow a different column
+              nClasses <- nlevels(classes)
+              rng <- range(rat$ID)
+              ## define the breaks
+              my.at <- seq(rng[1]-1, rng[2])
+              if (has.colorkey){
+                ## the labels will be placed vertically centered
+                my.labs.at <- seq(rng[1], rng[2])-0.5
+                colorkey <- modifyList(colorkey,
+                                       list(
+                                         at=my.at,
+                                         labels=
+                                         list(labels=as.character(classes),
+                                              at=my.labs.at)))
+              }
+            }
+
             ## Build the formula for levelplot
             form <- as.formula(paste(paste(names(df)[-c(1,2)], collapse='+'), 'x*y', sep='~'))
 
@@ -145,7 +173,7 @@ setMethod('levelplot',
                                    lwd=c(1, 0.4) # Two line widths, for main and minor contour lines
                                    ){
               ##Draw the regions with the panel requested by the user
-              if (region)levelPanel(..., at=at, contour=FALSE, labels=FALSE)
+              if (region) levelPanel(..., at=at, contour=FALSE, labels=FALSE)
               has.labels <- (is.logical(labels) && labels) || is.list(labels)
               mainTicks=(as.character(zscale$labels)!=FALSE)
               mainLabels <- list(labels=zscale$labels[mainTicks], cex=0.8)
@@ -168,13 +196,14 @@ setMethod('levelplot',
             
             ## And finally, the levelplot call
             if (missing(names.attr)){
-              names.attr <- layerNames(object)
-              } else {
-                if (length(names.attr) != nlayers(object))
-                  stop('Length of names.attr should match number of layers.')
-                }
+              names.attr <- objNames
+            } else {
+              if (length(names.attr) != nlayers(object))
+                stop('Length of names.attr should match number of layers.')
+            }
+            
             p <- levelplot(form, data=df,
-                           ## scales=scales,
+                           scales=scales,
                            aspect=aspect,
                            xlab=xlab, ylab=ylab, main = main, 
                            par.settings=par.settings,
@@ -186,12 +215,15 @@ setMethod('levelplot',
                            contour=contour, region=region, labels=labels,
                            strip=strip.custom(factor.levels=names.attr),
                            ## The panel depends on zscaleLog and contour
-                           panel=if (!is.null(zscaleLog) && has.contour) {
+                           panel=if (!is.null(zscaleLog) && has.contour && !isFactor) {
                              panelMixed 
                            } else {
                              requestedPanel 
                            },
                            ...)
+
+            if (isFactor) p <- update(p, at=my.at)
+            
             ## with the margins if needed
             if (nlayers(object)==1 && margin) {
               marginsLegend <- list(right=list(
